OiRA

Help

1. Préparation
2. Impliquer
3. Identification + Estimation
4. Plan d'action
5. Rapport
6. Avancement 0%

# Obtenez une évaluation des risques adaptée à votre organisation

Afin d'adapter l'évaluation des risques à votre organisation, il peut vous être demandé de :

- sélectionner ou sauter une/des situation(s) appropriée(s) ou non pour votre activité commerciale et cocher la/les case(s), si nécessaire
- répertorier de multiples unités commerciales, ou filiales, ou magasins, etc. Ces risques relatifs seront répétés pour chaque nom que vous avez saisi.

## Commercial manned guarding

Does your organisation provide commercial manned guarding? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Mobile partrolling/intervention after alarm

Does your organisation provide mobile patrolling / intervention after alarm? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Event security

Does your organisation provide event security? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

Scroll to top
Back

## profiling.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More